==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'A mit accent grave einfügen',
	'barre_adresse' => 'Adresse',
	'barre_aide' => 'Gestalten sie ihre Seite mit typografischen Kürzeln',
	'barre_alignerdroite' => 'Absatz [/rechtsbündig/] ausrichten',
	'barre_ancres' => 'Anker verwalten',
	'barre_barre' => 'Text durchstreichen',
	'barre_bulle' => 'Sprechblasenhilfe',
	'barre_c_cedille_maj' => 'C cédille  einfügen',
	'barre_cadre' => 'In &lt;cadre&gt;Textfeld&lt;/cadre&gt; einfügen',
	'barre_caracteres' => 'Sonderzeichen',
	'barre_centrer' => 'Absatz [|zentrieren|]',
	'barre_chercher' => 'Suchen / Ersetzen',
	'barre_clean' => 'Code aller HTML-Tags bereinigen',
	'barre_code' => '&lt;code&gt;Programmcode &lt;/code&gt; formatieren',
	'barre_desindenter' => 'Einrückungen aus Liste entfernen',
	'barre_e_accent_aigu' => 'E mit accent aigu einfügen',
	'barre_e_accent_grave' => 'E mit accent grave einfügen',
	'barre_ea' => 'æ einfügen',
	'barre_ea_maj' => 'Æ einfügen',
	'barre_encadrer' => 'Absatz mit [(Kasten)]',
	'barre_eo' => 'œ  einfügen',
	'barre_eo_maj' => 'Œ  einfügen',
	'barre_euro' => '€ Symbol  einfügen',
	'barre_exposant' => 'Text &lt;sup&gt;hochstellen&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Spezielle Formatierungen',
	'barre_galerie' => 'Galerie öffnen',
	'barre_gestion_anc_bulle' => 'Sprechblasenhilfe zum Anker',
	'barre_gestion_anc_caption' => 'Anker verwalten',
	'barre_gestion_anc_cible' => 'Zielanker',
	'barre_gestion_anc_inserer' => 'In Anker umwandeln',
	'barre_gestion_anc_nom' => 'Name des Ankers',
	'barre_gestion_anc_pointer' => 'Link zu Anker',
	'barre_gestion_caption' => 'Legende und Zusammenfassung',
	'barre_gestion_colonne' => 'Spaltenzahl',
	'barre_gestion_cr_casse' => 'Gross/Klein beachten',
	'barre_gestion_cr_changercasse' => 'Majusker/Gemeine tauschel',
	'barre_gestion_cr_changercassemajuscules' => 'In Majuskel umwandeln',
	'barre_gestion_cr_changercasseminuscules' => 'In Gemeine umwandeln',
	'barre_gestion_cr_chercher' => 'Suchen',
	'barre_gestion_cr_entier' => 'Ganzes Wort',
	'barre_gestion_cr_remplacer' => 'Ersetzen',
	'barre_gestion_cr_tout' => 'Alles ersetzen',
	'barre_gestion_entete' => 'Kopf',
	'barre_gestion_ligne' => 'Zeilenzahl',
	'barre_gestion_taille' => 'Feste Größe',
	'barre_glossaire' => 'Eintrag in [?glossaire] (Wikipedia)',
	'barre_gras' => '{{Fett}} setzen',
	'barre_guillemets' => 'In « Anführungszeichen » setzen.',
	'barre_guillemets_simples' => 'in “ doppelte Anführungszeichen ”',
	'barre_indenter' => 'Liste mit Einrückungen',
	'barre_inserer_cadre' => 'Vorformatierten Code einfügen (```)',
	'barre_inserer_caracteres' => 'Sonderzeichen einfügen',
	'barre_inserer_code' => 'Programmcode einfügen (`)',
	'barre_intertitre' => 'In {{{Zwischentitel}}} umwandeln',
	'barre_italic' => 'In {kursiv} umwandeln',
	'barre_langue' => 'Sprache / Kurzform',
	'barre_lien' => 'In [Hyperlink->http://...] umwandeln',
	'barre_lien_externe' => 'Externer Link',
	'barre_lien_input' => 'Bitte geben sie die Adresse ihrer Website an (Sie können eine Webadresse im Format http://www.meineseite.de, eine Mailadresse oder die Nummer eines Artikels dieser Website angeben.)',
	'barre_liste_ol' => 'Als nummerierte Liste formatieren',
	'barre_liste_ul' => 'Als Liste formatieren',
	'barre_lorem_ipsum' => 'Einen falschen Absatz einfügen',
	'barre_lorem_ipsum_3' => 'Drei falsche Absätze einfügen',
	'barre_miseenevidence' => '[*hervorheben*]',
	'barre_note' => 'In [[Fu',
	'barre_paragraphe' => 'Absatz einfügen',
	'barre_petitescapitales' => 'Text als &lt;sc&gt;Kapitälchen&lt;/sc&gt;',
	'barre_poesie' => 'Als &lt;Poesie&gt;Poésie&lt;/poesie&gt; formatieren',
	'barre_preview' => 'Vorschaumodus',
	'barre_quote' => '<quote>Nachricht zitieren</quote>',
	'barre_stats' => 'Statistiken des Texts anzeigen',
	'barre_tableau' => 'In einer Tabelle (bitte markieren) suchen und ersetzen',

	// C
	'config_info_enregistree' => 'Konfiguration gespeichert',

	// E
	'editer' => 'Bearbeiten',
	'explication_barre_outils_public' => 'Die CSS et Javaskripte der Werkzeugleiste
	(Erweiterung Federhalter) werden in den öffentlichen Bereich geladen und
	ermöglichen diese Werkzeugleiten in den Formularen der Foren, des Stift-Plugins
	und in weiteren Plugins einzusetzen, wenn die jeweilige Konfiguration es erlaubt.',
	'explication_barre_outils_public_2' => 'Sie können die Werkzeugleisten abschalten und 
	die Größe des Codes der  öffentlichen Seiten reduzieren.
	Das betrifft Eingabefelder von Foren und Plugins.',

	// I
	'info_barre_outils_public' => 'Öffentliche Werkzeugleiste',
	'info_porte_plume_titre' => 'Werkzeugleiste konfigurieren',

	// L
	'label_barre_outils_public_non' => 'Werkzeugleisten nicht im öffentlichen Bereich laden.',
	'label_barre_outils_public_oui' => 'Werkzeugleisten und Skripte im öffentlichen Bereich laden.',

	// V
	'voir' => 'Anzeigen'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=de
// ** ne pas modifier le fichier **

return [

	// B
	'barre_a_accent_grave' => 'A mit accent grave einfügen',
	'barre_adresse' => 'Adresse',
	'barre_aide' => 'Gestalten sie ihre Seite mit typografischen Kürzeln',
	'barre_alignerdroite' => 'Absatz [/rechtsbündig/] ausrichten',
	'barre_ancres' => 'Anker verwalten',
	'barre_barre' => 'Text durchstreichen',
	'barre_bulle' => 'Sprechblasenhilfe',
	'barre_c_cedille_maj' => 'C cédille  einfügen',
	'barre_cadre' => 'In &lt;cadre&gt;Textfeld&lt;/cadre&gt; einfügen',
	'barre_caracteres' => 'Sonderzeichen',
	'barre_centrer' => 'Absatz [|zentrieren|]',
	'barre_chercher' => 'Suchen / Ersetzen',
	'barre_clean' => 'Code aller HTML-Tags bereinigen',
	'barre_code' => '&lt;code&gt;Programmcode &lt;/code&gt; formatieren',
	'barre_desindenter' => 'Einrückungen aus Liste entfernen',
	'barre_e_accent_aigu' => 'E mit accent aigu einfügen',
	'barre_e_accent_grave' => 'E mit accent grave einfügen',
	'barre_ea' => 'æ einfügen',
	'barre_ea_maj' => 'Æ einfügen',
	'barre_encadrer' => 'Absatz mit [(Kasten)]',
	'barre_eo' => 'œ  einfügen',
	'barre_eo_maj' => 'Œ  einfügen',
	'barre_euro' => '€ Symbol  einfügen',
	'barre_exposant' => 'Text &lt;sup&gt;hochstellen&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Spezielle Formatierungen',
	'barre_galerie' => 'Galerie öffnen',
	'barre_gestion_anc_bulle' => 'Sprechblasenhilfe zum Anker',
	'barre_gestion_anc_caption' => 'Anker verwalten',
	'barre_gestion_anc_cible' => 'Zielanker',
	'barre_gestion_anc_inserer' => 'In Anker umwandeln',
	'barre_gestion_anc_nom' => 'Name des Ankers',
	'barre_gestion_anc_pointer' => 'Link zu Anker',
	'barre_gestion_caption' => 'Legende und Zusammenfassung',
	'barre_gestion_colonne' => 'Spaltenzahl',
	'barre_gestion_cr_casse' => 'Gross/Klein beachten',
	'barre_gestion_cr_changercasse' => 'Majusker/Gemeine tauschel',
	'barre_gestion_cr_changercassemajuscules' => 'In Majuskel umwandeln',
	'barre_gestion_cr_changercasseminuscules' => 'In Gemeine umwandeln',
	'barre_gestion_cr_chercher' => 'Suchen',
	'barre_gestion_cr_entier' => 'Ganzes Wort',
	'barre_gestion_cr_remplacer' => 'Ersetzen',
	'barre_gestion_cr_tout' => 'Alles ersetzen',
	'barre_gestion_entete' => 'Kopf',
	'barre_gestion_ligne' => 'Zeilenzahl',
	'barre_gestion_taille' => 'Feste Größe',
	'barre_glossaire' => 'Eintrag in [?glossaire] (Wikipedia)',
	'barre_gras' => '{{Fett}} setzen',
	'barre_guillemets' => 'In « Anführungszeichen » setzen.',
	'barre_guillemets_simples' => 'in “ doppelte Anführungszeichen ”',
	'barre_indenter' => 'Liste mit Einrückungen',
	'barre_inserer_cadre' => 'Vorformatierten Code einfügen (```)',
	'barre_inserer_caracteres' => 'Sonderzeichen einfügen',
	'barre_inserer_code' => 'Programmcode einfügen (`)',
	'barre_intertitre' => 'In {{{Zwischentitel}}} umwandeln',
	'barre_italic' => 'In {kursiv} umwandeln',
	'barre_langue' => 'Sprache / Kurzform',
	'barre_lien' => 'In [Hyperlink->http://...] umwandeln',
	'barre_lien_externe' => 'Externer Link',
	'barre_lien_input' => 'Bitte geben sie die Adresse ihrer Website an (Sie können eine Webadresse im Format http://www.meineseite.de, eine Mailadresse oder die Nummer eines Artikels dieser Website angeben.)',
	'barre_liste_ol' => 'Als nummerierte Liste formatieren',
	'barre_liste_ul' => 'Als Liste formatieren',
	'barre_lorem_ipsum' => 'Einen falschen Absatz einfügen',
	'barre_lorem_ipsum_3' => 'Drei falsche Absätze einfügen',
	'barre_miseenevidence' => '[*hervorheben*]',
	'barre_note' => 'In [[Fu',
	'barre_paragraphe' => 'Absatz einfügen',
	'barre_petitescapitales' => 'Text als &lt;sc&gt;Kapitälchen&lt;/sc&gt;',
	'barre_poesie' => 'Als &lt;Poesie&gt;Poésie&lt;/poesie&gt; formatieren',
	'barre_preview' => 'Vorschaumodus',
	'barre_quote' => '<quote>Nachricht zitieren</quote>',
	'barre_stats' => 'Statistiken des Texts anzeigen',
	'barre_tableau' => 'In einer Tabelle (bitte markieren) suchen und ersetzen',

	// C
	'config_info_enregistree' => 'Konfiguration gespeichert',

	// E
	'editer' => 'Bearbeiten',
	'explication_barre_outils_public' => 'Die CSS et Javaskripte der Werkzeugleiste
	(Erweiterung Federhalter) werden in den öffentlichen Bereich geladen und
	ermöglichen diese Werkzeugleiten in den Formularen der Foren, des Stift-Plugins
	und in weiteren Plugins einzusetzen, wenn die jeweilige Konfiguration es erlaubt.',
	'explication_barre_outils_public_2' => 'Sie können die Werkzeugleisten abschalten und 
	die Größe des Codes der  öffentlichen Seiten reduzieren.
	Das betrifft Eingabefelder von Foren und Plugins.',

	// I
	'info_barre_outils_public' => 'Öffentliche Werkzeugleiste',
	'info_porte_plume_titre' => 'Werkzeugleiste konfigurieren',

	// L
	'label_barre_outils_public_non' => 'Werkzeugleisten nicht im öffentlichen Bereich laden.',
	'label_barre_outils_public_oui' => 'Werkzeugleisten und Skripte im öffentlichen Bereich laden.',

	// V
	'voir' => 'Anzeigen',
];
